@@ -2,7 +2,7 @@ import ast
 import asyncio
 import json
 import logging
-
+from enum import StrEnum
 import socketio
 from aiortc import MediaStreamTrack, RTCPeerConnection, RTCIceServer, RTCConfiguration
 from aiortc.contrib.media import MediaRelay, MediaBlackhole
@@ -15,13 +15,28 @@ from threading import Thread
 relay = MediaRelay()
 
 
+class GSCOMMAND(StrEnum):
+    PAN = 'pan',
+    TILT = 'tilt',
+    ZOOM = 'zoom',
+    FOCUS = 'focus',
+    SNAPSHOT = 'snapshot',
+    IRCUT = 'ircut'
+
+
 class GSPeerConnectionWatcher:
 
+    def __init__(self):
+        self.sio = socketio.AsyncClient()
+
+    def sendCommand(self, command: GSCOMMAND, value):
+        await self.sio.emit("command", {"type": command, "value": value})
+
     @classmethod
     async def create(cls, gsdbs, target, onframe=None, onmessage=None, ontrack=None, ontrackended=None):
         self = GSPeerConnectionWatcher()
         self.rtconfiList = []
-        self.sio = socketio.AsyncClient()
+        # self.sio = socketio.AsyncClient()
         self.gsdbs = gsdbs
         self.onframe = onframe
         self.target = target
@@ -80,8 +95,6 @@ class GSPeerConnectionWatcher:
                                  "sdp": {"type": self.peerConnections.localDescription.type,
                                          "sdp": self.peerConnections.localDescription.sdp}})
 
-
-
         @self.sio.event
         async def answer(id, description):
             if isinstance(description, dict):
@@ -94,7 +107,6 @@ class GSPeerConnectionWatcher:
         async def disconnectBroadcaster(id, target):
             await self.ontrackended(self.gsdbs, target)
 
-
         if "localhost" in self.gsdbs.credentials["signalserver"]:
             connectURL = f'{self.gsdbs.credentials["signalserver"]}:{str(self.gsdbs.credentials["signalport"])}'
         else:
